"""
~~~~~~~~~
Constants
~~~~~~~~~

"""

default_exclude = None
"""Default value for asdict_exclude"""
default_exclude_underscore = True
"""Default value for exclude_underscore if not set"""
default_fromdict_allow_pk = False
"""Default value for fromdict_allow_pk if not set"""
